@@ -33,80 +33,69 @@
 #include <uthash.h>
 
 #include "config.h"
+#include "digest.h"
 #include "download.h"
 #include "filemap.h"
+#include "itemset.h"
 #include "logging.h"
 #include "outfmt.h"
 #include "persist_dir.h"
 #include "persist_file.h"
-#include "persist_items.h"
 #include "placeholders.h"
 #include "rc.h"
 #include "text.h"
 #include "util.h"
 
-typedef struct
+struct opts
 {
     const char *uid;
     bool dry_mark : 1;
     bool dry_exec : 1;
     bool catch_up : 1;
-} opts_t;
+};
 
-typedef struct
+struct feed_info
 {
     const char *name;
-    const rc_feed_t *config;
-    persist_file_t *persist_file;
+    const struct rc_feed *config;
+    struct persist_file *persist_file;
     bool own_persist;
     bool ofmt_loaded;
     bool enabled;
     struct ctx *global_ctx;
 
     UT_hash_handle hh;
-} feed_info_t;
+};
 
-typedef struct
+struct feed_map
 {
-    feed_info_t *slots;
-    feed_info_t *map;
+    struct feed_info *slots;
+    struct feed_info *map;
     unsigned size;
-} feed_map_t;
+};
 
-typedef struct ctx
+struct ctx
 {
-    const rc_t *rc;
-    download_t *dload;
-    ofmt_t *ofmt;
-    const opts_t opts;
-    persist_dir_t *persist_dir;
+    struct rc *rc;
+    struct download *dload;
+    struct ofmt *ofmt;
+    const struct opts opts;
+    struct persist_dir *persist_dir;
+    struct digest *digest;
     unsigned failures;
-} ctx_t;
+};
 
-typedef struct
-{
-    persist_item_t persist_item;
-    UT_hash_handle hh;
-} feed_item_t;
-
-typedef struct
-{
-    feed_item_t *slots;
-    feed_item_t *map;
-    unsigned size;
-} items_map_t;
-
-typedef enum
+enum process_status
 {
     ps_success,
     ps_fail_critical,
     ps_fail_feed,
     ps_fail_item,
-} process_status_t;
+};
 
-static void feed_map_free(feed_map_t *feed_map)
+static void feed_map_free(struct feed_map *feed_map)
 {
-    feed_info_t *feed_info, *tmp;
+    struct feed_info *feed_info, *tmp;
 
     HASH_ITER(hh, feed_map->map, feed_info, tmp) {
         if (feed_info->own_persist)
@@ -116,19 +105,19 @@ static void feed_map_free(feed_map_t *feed_map)
     free(feed_map->slots);
 }
 
-static int feed_map_init(feed_map_t *feed_map, ctx_t *ctx)
+static int feed_map_init(struct feed_map *feed_map, struct ctx *ctx)
 {
-    /* Each configured feed is associated with a feed_info_t object, indexed
-     * into feed_map by feed name. */
+    /* Each configured feed is associated with a struct feed_info object,
+     * indexed into feed_map by feed name. */
 
-    feed_info_t *slots;
+    struct feed_info *slots;
     unsigned size;
     bool any_enabled = false;
 
     size = rc_n_feeds(ctx->rc);
     if (size == 0) {
         notice("no feeds defined");
-        *feed_map = (feed_map_t){};
+        *feed_map = (struct feed_map){};
         return 0;
     }
 
@@ -138,14 +127,14 @@ static int feed_map_init(feed_map_t *feed_map, ctx_t *ctx)
         return -1;
     }
 
-    *feed_map = (feed_map_t){
+    *feed_map = (struct feed_map){
         .slots = slots,
         .size = size,
     };
 
     for (unsigned i = 0; i < size; i ++) {
-        const rc_feed_t *rc_feed;
-        feed_info_t *feed_info;
+        const struct rc_feed *rc_feed;
+        struct feed_info *feed_info;
         size_t namelen;
 
         rc_feed = rc_get_feed(ctx->rc, i);
@@ -158,7 +147,7 @@ static int feed_map_init(feed_map_t *feed_map, ctx_t *ctx)
         }
 
         feed_info = slots++;
-        *feed_info = (feed_info_t){
+        *feed_info = (struct feed_info){
             .name = rc_feed->name,
             .config = rc_feed,
             .enabled = ctx->opts.uid
@@ -184,9 +173,9 @@ fail:
     return -1;
 }
 
-static int feed_info_set_persist(feed_info_t *feed_info)
+static int feed_info_set_persist(struct feed_info *feed_info)
 {
-    persist_file_t *persist_file;
+    struct persist_file *persist_file;
 
     persist_file = persist_file_new(
         feed_info->global_ctx->persist_dir,
@@ -217,11 +206,11 @@ static void usage(const char *progname)
     fprintf(stderr, "Usage: %s [-cDdhqVv] [[-i] identifier]\n", progname);
 }
 
-static opts_t read_opts(int argc, char **argv)
+static struct opts read_opts(int argc, char **argv)
 {
     int opt;
 
-    opts_t result = {};
+    struct opts result = {};
 
     while (opt = getopt(argc, argv, "cDdhi:qVv"), opt != -1)
         switch (opt) {
@@ -250,7 +239,7 @@ static opts_t read_opts(int argc, char **argv)
             break;
 
         case 'V':
-            puts(PACKAGE_STRING);
+            puts(PROJECT_NAME " " PROJECT_VERSION_FULL);
             exit(EXIT_SUCCESS);
 
         case 'v':
@@ -271,9 +260,9 @@ static opts_t read_opts(int argc, char **argv)
     return result;
 }
 
-static ofmt_t * setup_ofmt(void)
+static struct ofmt * setup_ofmt(void)
 {
-    ofmt_t *ofmt;
+    struct ofmt *ofmt;
 
     ofmt = ofmt_new();
     if (!ofmt)
@@ -287,11 +276,11 @@ static ofmt_t * setup_ofmt(void)
     return ofmt;
 }
 
-static persist_dir_t *setup_persist(const rc_t *rc)
+static struct persist_dir *setup_persist(const struct rc *rc)
 {
     const char *persist_dir_path;
     int basedir;
-    persist_dir_t *persist_dir;
+    struct persist_dir *persist_dir;
 
     persist_dir_path = rc_get_global(rc)->persist_dir;
 
@@ -310,24 +299,24 @@ static persist_dir_t *setup_persist(const rc_t *rc)
     return persist_dir;
 }
 
-static int sync_persist_dir(const ctx_t *ctx, feed_map_t *feed_map)
+static int sync_persist_dir(const struct ctx *ctx, struct feed_map *feed_map)
 {
     /* Loop over the persisted feeds on the filesystem:
-     * - Index the persist_file_t object if the corresponding feed exists in
+     * - Index the persist_file object if the corresponding feed exists in
      *   the feed map (that is, the feed is configured in the rc file;.
      * - Unlink the file if the feed map does not contain it (that is, it was
      *   removed from the configuration file).
      */
 
     void *aux;
-    persist_file_t *persist_file;
+    struct persist_file *persist_file;
 
     aux = NULL;
     debug("synchronize persist_dir");
     while (persist_file = persist_dir_iter(ctx->persist_dir, &aux), persist_file) {
         const char *pfname;
         unsigned pfnamelen;
-        feed_info_t *feed_info;
+        struct feed_info *feed_info;
 
         pfname = persist_file_name(persist_file);
         pfnamelen = strlen(pfname);
@@ -367,80 +356,9 @@ static int sync_persist_dir(const ctx_t *ctx, feed_map_t *feed_map)
     return 0;
 }
 
-static int items_map_init(items_map_t *imap, const persist_items_t *p_items)
-{
-    unsigned n;
-    feed_item_t *slots;
-
-    n = persist_items_size(p_items);
-    if (n == 0) {
-        *imap = (items_map_t){};
-        return 0;
-    }
-
-    slots = reallocarray(NULL, n, sizeof(feed_item_t));
-    if (!slots) {
-        warn("reallocarray");
-        return -1;
-    }
-
-    *imap = (items_map_t){
-        .slots = slots,
-        .size = n,
-    };
-
-    debug(" loading from persist_file %u items:", n);
-    for (unsigned i = 0; i < n; i ++) {
-        const persist_item_t *p_item;
-        feed_item_t *f_item;
-
-        p_item = persist_items_get(p_items, i);
-
-        HASH_FIND(hh, imap->map, p_item->data, p_item->len, f_item);
-        if (f_item) {
-            /* The persist_items implementation does not check for duplications,
-             * however this should never happen. The items are in fact loaded
-             * into a hash map at every execution, updated, and then stored
-             * again.  Still the file might have been tampered with (why?), so
-             * we should probably not crash. */
-            warnx("Duplicated feed item: %.*s",
-                p_item->len,
-                (const char *)p_item->data
-            );
-            return -1;
-        }
-
-        f_item = &slots[i];
-        *f_item = (feed_item_t){
-            .persist_item = *p_item,
-        };
-
-        debug("   item guid \"%.*s\"",
-            (int)f_item->persist_item.len,
-            (char *)f_item->persist_item.data
-        );
-        HASH_ADD_KEYPTR(hh, imap->map,
-            f_item->persist_item.data,
-            f_item->persist_item.len,
-            f_item
-        );
-    }
-
-    return 0;
-}
-
-static void items_map_free(items_map_t *imap)
-{
-    feed_item_t *fi, *tmp;
-
-    HASH_ITER(hh, imap->map, fi, tmp)
-        HASH_DELETE(hh, imap->map, fi);
-    free(imap->slots);
-}
-
-static process_status_t parse_feed(const feed_info_t *feed_info,
-                                   const filemap_t *fmap,
-                                   mrss_t **xml)
+static enum process_status parse_feed(const struct feed_info *feed_info,
+                                      const struct filemap *fmap,
+                                      mrss_t **xml)
 {
     mrss_error_t error;
     const char *kind, *reason;
@@ -480,15 +398,15 @@ static process_status_t parse_feed(const feed_info_t *feed_info,
     return ps_fail_feed;
 }
 
-static process_status_t load_outfmt(feed_info_t *feed_info)
+static enum process_status load_outfmt(struct feed_info *feed_info)
 {
-    static const ofmt_mode_t ofmt_mode_of[] = {
+    static const enum ofmt_mode ofmt_mode_of[] = {
         [rc_hdl_pipe] = ofmt_mode_pipe,
         [rc_hdl_print] = ofmt_mode_print,
         [rc_hdl_exec] = ofmt_mode_exec,
     };
-    const rc_feed_t *config = feed_info->config;
-    ofmt_t *ofmt = feed_info->global_ctx->ofmt;
+    const struct rc_feed *config = feed_info->config;
+    struct ofmt *ofmt = feed_info->global_ctx->ofmt;
 
     if (ofmt_compile(ofmt,
                      ofmt_mode_of[config->handler],
@@ -508,19 +426,13 @@ static process_status_t load_outfmt(feed_info_t *feed_info)
     return ps_fail_feed;
 }
 
-static const char *x_item_guid(const mrss_item_t *x_item)
-{
-    return x_item->guid ?: x_item->link;
-}
-
-static process_status_t process_item_print(const feed_info_t *feed_info,
-                                           const mrss_item_t *x_item,
-                                           const placeholder_extra_t *extra_data)
+static enum process_status process_item_print(const struct feed_info *feed_info,
+                                         const mrss_item_t *x_item,
+                                         const struct placeholder_extra *extra_data)
 {
     char buffer[256];
 
-    printf("ITEM: %s\n", x_item_guid(x_item));
-    printf(" incremental_id: %u\n", extra_data->incremental_id);
+    printf("ITEM: %u\n", extra_data->incremental_id);
 
     #define print_if(fmt, val) if (val) printf(fmt, val)
     print_if(" title: %s\n", x_item->title);
@@ -556,27 +468,27 @@ static process_status_t process_item_print(const feed_info_t *feed_info,
     return ps_success;
 }
 
-static process_status_t process_item(feed_info_t *feed_info,
+static enum process_status process_item(struct feed_info *feed_info,
                                      const mrss_item_t *parsed_item,
-                                     const placeholder_extra_t *extra_data)
+                                     const struct placeholder_extra *extra_data)
 {
-    const rc_feed_t *config = feed_info->config;
+    const struct rc_feed *config = feed_info->config;
 
     if (config->handler == rc_hdl_print && config->ofmt.spec == NULL)
         return process_item_print(feed_info, parsed_item, extra_data);
 
     if (!feed_info->ofmt_loaded) {
-        process_status_t pstatus;
+        enum process_status pstatus;
 
         pstatus = load_outfmt(feed_info);
         if (pstatus != ps_success)
             return pstatus;
     }
 
-    ctx_t *ctx = feed_info->global_ctx;
+    struct ctx *ctx = feed_info->global_ctx;
     placeholders_set_extra(ctx->ofmt, extra_data);
 
-    ofmt_evaluate_params_t params = {
+    struct ofmt_evaluate_params params = {
         .item = (mrss_t *)parsed_item,
         .dry_run = ctx->opts.dry_exec,
         .opt_subproc_chdir = feed_info->config->chdir,
@@ -591,20 +503,77 @@ static process_status_t process_item(feed_info_t *feed_info,
     return ps_fail_item;
 }
 
-static process_status_t process_feed(feed_info_t *feed_info,
-                                     const filemap_t *fmap)
+static int item_digest(struct digest *digest,
+                       const mrss_item_t *x_item,
+                       uint8_t *result)
 {
-    process_status_t pstatus;
-    items_map_t imap = {};
+    int e = -1;
+
+    if (digest_add_cstr(digest, x_item->title))
+        goto cleanup;
+
+    if (digest_add_cstr(digest, x_item->guid))
+        goto cleanup;
+
+    if (digest_add_cstr(digest, x_item->link))
+        goto cleanup;
+
+    /* TODO: maybe more fields?
+     * Or allow the user to select the fields that should participate
+     * in the digest (by configuration, for individual feeds).
+     */
+
+    if (digest_add_cstr(digest, x_item->pubDate))
+        goto cleanup;
+
+    if (digest_finish(digest, result, digest_buflen))
+        goto cleanup;
+
+    e = 0;
+cleanup:
+    digest_reset(digest);
+    return e;
+}
+
+static void debug_print_old_items(const struct itemset *old_items)
+{
+    const void *aux = NULL;
+    const uint8_t *data;
+    uint16_t data_len;
+
+    if (!debug_enabled)
+        return;
+
+    warnx(" loaded from persist_file: %hu items", itemset_get_size(old_items));
+    while (itemset_iter(old_items, &aux, &data, &data_len))
+        debug("   item guid \"%.*s\"", data_len, (const char *)data);
+}
+
+static void to_hex(char *dst, const uint8_t *src, size_t src_len)
+{
+    const char digits[] = "0123456789abcdef";
+
+    for (size_t i = 0; i < src_len - 1; i++) {
+        dst[2 * i]     = digits[(src[i] & 0xf0) >> 4];
+        dst[2 * i + 1] = digits[(src[i] & 0x0f) >> 0];
+    }
+    dst[src_len - 1] = 0;
+}
+
+static enum process_status process_feed(struct feed_info *feed_info,
+                                        const struct filemap *fmap)
+{
+    enum process_status pstatus;
     mrss_t *xml = NULL;
     unsigned incremental_id;
     bool catch_up = feed_info->global_ctx->opts.catch_up;
-    persist_items_t *old_items = NULL, *new_items = NULL;
-    unsigned seen_before = 0;
+    struct digest *digest = feed_info->global_ctx->digest;
+    struct itemset *old_items = NULL, *new_items = NULL;
+    unsigned old_news = 0, new_news = 0;
 
     info("processing %s", feed_info->name);
 
-    new_items = persist_items_new(0);
+    new_items = itemset_new();
     if (!new_items) {
         pstatus = ps_fail_critical;
         goto exit;
@@ -613,10 +582,8 @@ static process_status_t process_feed(feed_info_t *feed_info,
     /* If old_items is NULL, this feed is processed for the first time. */
     old_items = persist_file_swap_items(feed_info->persist_file, NULL);
 
-    if (old_items && items_map_init(&imap, old_items)) {
-        pstatus = ps_fail_critical;
-        goto exit;
-    }
+    if (old_items)
+        debug_print_old_items(old_items);
 
     pstatus = parse_feed(feed_info, fmap, &xml);
     if (pstatus != ps_success)
@@ -625,39 +592,37 @@ static process_status_t process_feed(feed_info_t *feed_info,
     incremental_id = persist_file_get_incrid(feed_info->persist_file);
     debug(" loading from XML");
     for (mrss_item_t *x_item = xml->item; x_item; x_item = x_item->next) {
-        const char *uid;
-        size_t uid_len;
-        feed_item_t *f_item;
+        uint8_t uid[digest_buflen];
+        char uid_str[digest_buflen * 2 + 1];
+        bool seen_before;
 
-        uid = x_item->guid ?: x_item->link;
-        if (!uid) {
-            notice("Bad item in %s: missing guid and link", feed_info->name);
+        if (item_digest(digest, x_item, uid)) {
+            notice("Bad item in %s: bad item id", feed_info->name);
             continue;
         }
-        uid_len = strlen(uid);
+        to_hex(uid_str, uid, sizeof uid);
 
-        HASH_FIND(hh, imap.map, uid, uid_len, f_item);
-        debug(" %c item guid \"%s\"", f_item ? '=' : '+', uid);
+        seen_before = old_items && itemset_exists(old_items, uid, sizeof uid);
+        debug(" %c item guid \"%s\"", seen_before ? '=' : '+', uid_str);
 
-        if (f_item) {
-            /* Seen before.  The item is added to the new set of items, as it
-             * has not been removed from the feed XML. */
-            seen_before ++;
-            if (persist_items_add(new_items, &f_item->persist_item)) {
-                pstatus = ps_fail_critical;
-                goto exit;
-            }
-            continue;
-        }
+        if (seen_before)
+            old_news++;
+        else
+            new_news++;
 
-        if (!catch_up) {
-            pstatus = process_item(feed_info, x_item,
-                &(placeholder_extra_t){
-                    .incremental_id = incremental_id,
-                    .feed_title = xml->title,
-                    .feed_identifier = feed_info->name,
-                }
-            );
+        if (!seen_before) {
+
+            if (catch_up)
+                pstatus = ps_success;
+            else
+                pstatus = process_item(feed_info, x_item,
+                    &(struct placeholder_extra){
+                        .incremental_id = incremental_id,
+                        .feed_title = xml->title,
+                        .feed_identifier = feed_info->name,
+                    }
+                );
+            incremental_id++;
 
             switch (pstatus) {
             case ps_success:
@@ -671,31 +636,22 @@ static process_status_t process_feed(feed_info_t *feed_info,
             }
         }
 
-        if (persist_items_add(new_items, &(persist_item_t){
-                .data = (void *)uid,
-                .len = uid_len,
-                })) {
+        switch (itemset_add(new_items, uid, sizeof uid)) {
+        case itemset_edup:
+            notice("Duplicated item in feed %s: %s", feed_info->name, uid_str);
+            break;
+        case itemset_emax:
+            notice("Too many entries in feed %s", feed_info->name);
+            break;
+        case itemset_eok:
+            break;
+        case itemset_esys:
             pstatus = ps_fail_critical;
             goto exit;
         }
-
-        incremental_id ++;
     }
 
-    /* Transfer ownership of the parsed xml to new_items */
-    persist_items_set_store(new_items, xml, (void (*)(void *))mrss_free);
-    xml = NULL;
-
-    if (info_enabled) {
-        unsigned unseen;
-
-        unseen = persist_items_size(new_items) - seen_before;
-
-        if (debug_enabled)
-            debug(" updating with %u new items", unseen);
-        else if (unseen > 0)
-            info("updates for %s: %u items", feed_info->name, unseen);
-    }
+    info("feed %s: old_news=%u new_news=%u", feed_info->name, old_news, new_news);
 
     /* Transfer ownership of new_items to the persist_file */
     (void)persist_file_swap_items(feed_info->persist_file, new_items);
@@ -714,20 +670,19 @@ static process_status_t process_feed(feed_info_t *feed_info,
 exit:
     if (xml)
         mrss_free(xml);
-    items_map_free(&imap);
-    persist_items_del(old_items);
-    persist_items_del(new_items);
+    itemset_del(old_items);
+    itemset_del(new_items);
 
     return pstatus;
 }
 
 static int on_downloaded(void *opaque,
-                         download_status_t dstatus,
+                         enum download_status dstatus,
                          const char *errmsg,
-                         const filemap_t *file_map)
+                         const struct filemap *file_map)
 {
-    feed_info_t *feed_info = opaque;
-    process_status_t pstatus = ps_fail_feed;
+    struct feed_info *feed_info = opaque;
+    enum process_status pstatus = ps_fail_feed;
 
     switch (dstatus) {
     case dl_complete:
@@ -755,7 +710,7 @@ static int on_downloaded(void *opaque,
     return pstatus == ps_fail_critical ? -1 : 0;
 }
 
-static int schedule_feed_download(feed_info_t *feed_info)
+static int schedule_feed_download(struct feed_info *feed_info)
 {
     debug("schedule retrieval of url %s for %s",
         feed_info->config->url,
@@ -769,10 +724,10 @@ static int schedule_feed_download(feed_info_t *feed_info)
     );
 }
 
-static int run(ctx_t *ctx)
+static int run(struct ctx *ctx)
 {
     int e = -1;
-    feed_map_t feed_map;
+    struct feed_map feed_map;
 
     if (feed_map_init(&feed_map, ctx))
         return -1;
@@ -781,7 +736,7 @@ static int run(ctx_t *ctx)
         goto exit;
 
     for (unsigned i = 0; i < feed_map.size; ++i) {
-        feed_info_t *feed_info = &feed_map.slots[i];
+        struct feed_info *feed_info = &feed_map.slots[i];
 
         if (!feed_info->enabled)
             continue;
@@ -808,6 +763,7 @@ static int run(ctx_t *ctx)
 
     e = ctx->failures ? -1 : 0;
 exit:
+    download_abort(ctx->dload);
     feed_map_free(&feed_map);
     return e;
 }
@@ -815,49 +771,44 @@ exit:
 int main(int argc, char **argv)
 {
     int e = -1;
-    rc_t *rc = NULL;
-    download_t *dload = NULL;
-    ofmt_t *ofmt = NULL;
-    opts_t opts;
-    persist_dir_t *persist_dir = NULL;
+    struct ctx ctx = {
+        .opts = read_opts(argc, argv),
+    };
 
 #ifdef HAVE_PLEDGE
     if (pledge("stdio rpath wpath cpath inet dns proc exec", NULL) == -1)
         err(EXIT_FAILURE, "pledge");
 #endif
 
-    opts = read_opts(argc, argv);
-
-    rc = rc_new();
-    if (!rc)
+    ctx.rc = rc_new();
+    if (!ctx.rc)
         goto exit;
 
-    if (rc_load(rc))
+    if (rc_load(ctx.rc))
         goto exit;
 
-    ofmt = setup_ofmt();
-    if (!ofmt)
+    ctx.dload = download_new(true, rc_get_global(ctx.rc)->jobs);
+    if (!ctx.dload)
         goto exit;
 
-    dload = download_new(true, rc_get_global(rc)->jobs);
-    if (!dload)
+    ctx.ofmt = setup_ofmt();
+    if (!ctx.ofmt)
         goto exit;
 
-    persist_dir = setup_persist(rc);
-    if (!persist_dir)
+    ctx.persist_dir = setup_persist(ctx.rc);
+    if (!ctx.persist_dir)
         goto exit;
 
-    e = run(&(ctx_t){
-        .rc = rc,
-        .dload = dload,
-        .ofmt = ofmt,
-        .opts = opts,
-        .persist_dir = persist_dir,
-    });
+    ctx.digest = digest_new();
+    if (!ctx.digest)
+        goto exit;
+
+    e = run(&ctx);
 exit:
-    persist_dir_del(persist_dir);
-    download_del(dload);
-    ofmt_del(ofmt);
-    rc_free(rc);
+    digest_del(ctx.digest);
+    persist_dir_del(ctx.persist_dir);
+    ofmt_del(ctx.ofmt);
+    download_del(ctx.dload);
+    rc_free(ctx.rc);
     return e ? EXIT_FAILURE : EXIT_SUCCESS;
 }
