@@ -22,38 +22,39 @@
 
 #include <stdbool.h>
 
-typedef struct download download_t;
+struct download;
+struct filemap;
 
-typedef enum {
+enum download_status {
     dl_complete,
     dl_aborted,
     dl_fetch_failure,
     dl_sys_failure,
-} download_status_t;
+};
 
-typedef struct filemap filemap_t;
-
-/* download_cb_t - download callback.
+/* download_callback - download callback.
  *
  * Expected to return 0 on success.  If the return value is not 0 all
  * downloading processes will be interrupted.
  */
-typedef int (*download_cb_t)(
+typedef int (*download_callback)(
     void *opaque,
-    download_status_t,
+    enum download_status,
     const char *errmsg,
-    const filemap_t *filemap
+    const struct filemap *filemap
 );
 
-download_t *download_new(bool global_init, unsigned maxjobs);
+struct download *download_new(bool global_init, unsigned maxjobs);
 
 int download_schedule(
-    download_t *,
+    struct download *,
     const char *url,
-    download_cb_t,
+    download_callback,
     void *opaque
 );
 
-int download_perform(download_t *);
+int download_perform(struct download *);
 
-void download_del(download_t *);
+void download_abort(struct download *);
+
+void download_del(struct download *);
