@@ -21,19 +21,7 @@ static int filesize(int fd, size_t *s)
     return 0;
 }
 
-filemap_t *filemap_new(void)
-{
-    filemap_t *fmap;
-
-    fmap = malloc(sizeof(*fmap));
-    if (fmap)
-        *fmap = (filemap_t){};
-    else
-        warn("malloc");
-    return fmap;
-}
-
-int filemap_load_fd(filemap_t *fmap, int fd)
+int filemap_load_fd(struct filemap *fmap, int fd)
 {
     size_t size;
     void *mapped;
@@ -41,7 +29,7 @@ int filemap_load_fd(filemap_t *fmap, int fd)
     if (filesize(fd, &size) == -1)
         return -1;
 
-    *fmap = (filemap_t) {};
+    *fmap = (struct filemap) {};
     if (size == 0)
         /* An empty file is not an error.  It is handled as there
          * was no file in the first place */
@@ -53,7 +41,7 @@ int filemap_load_fd(filemap_t *fmap, int fd)
         return -1;
     }
 
-    *fmap = (filemap_t) {
+    *fmap = (struct filemap) {
         .memory = mapped,
         .size = size,
     };
@@ -63,7 +51,7 @@ success:
     return 0;
 }
 
-int filemap_load_path(filemap_t *fmap, const char *fname)
+int filemap_load_path(struct filemap *fmap, const char *fname)
 {
     int fd;
 
@@ -81,20 +69,11 @@ int filemap_load_path(filemap_t *fmap, const char *fname)
     return 0;
 }
 
-void filemap_unload(filemap_t *fmap)
+void filemap_unload(struct filemap *fmap)
 {
     if (fmap->memory == MAP_FAILED || !fmap->memory)
         return;
 
     munmap(fmap->memory, fmap->size);
-    *fmap = (filemap_t) {};
-}
-
-void filemap_del(filemap_t *fmap)
-{
-    if (!fmap)
-        return;
-
-    filemap_unload(fmap);
-    free(fmap);
+    *fmap = (struct filemap) {};
 }
