@@ -22,13 +22,13 @@
 
 #include <stddef.h>
 
-typedef struct {
+struct launcher_run {
     const char * const * argv;
     const char * chdir_to;
     struct {
         void *bytes;
         size_t len;
     } input;
-} launcher_run_t;
+};
 
-int launcher_execvp(const launcher_run_t *, int *status);
+int launcher_execvp(const struct launcher_run *, int *status);
