@@ -22,15 +22,11 @@
 
 extern unsigned g_verbosity_level;
 
-#define whisper_enabled (g_verbosity_level >= 2)
-#define say_enabled (g_verbosity_level >= 1)
+#define debug_enabled (g_verbosity_level > 2)
+#define debug(...) do { if (debug_enabled) warnx(__VA_ARGS__); } while(0)
 
-#define say(...) do { \
-    if (say_enabled) \
-        warnx(__VA_ARGS__); \
-    } while(0)
+#define info_enabled (g_verbosity_level > 1)
+#define info(...) do { if (info_enabled) warnx(__VA_ARGS__); } while(0)
 
-#define whisper(...) do { \
-    if (whisper_enabled) \
-        warnx(__VA_ARGS__); \
-    } while(0)
+#define notice_enabled (g_verbosity_level > 0)
+#define notice(...) do { if (notice_enabled) warnx(__VA_ARGS__); } while(0)
