@@ -38,7 +38,17 @@
 
 enum {
     /* TODO: these assignments are arbitrary, and they
-     * should be reviewed. */
+     * should be reviewed.
+     *
+     * Clever way to print struct size:
+     *  char (*__kaboom)[sizeof( struct foo )] = 1;
+     * (credits: https://stackoverflow.com/a/35261673)
+     *
+     * Current sizes:
+     *  sizeof struct subproc => 3088
+     *  sizeof struct print => 2056    <- can be more.
+     *  sizeof struct ofmt => 3192
+     */
     max_iov_len = 3 * 32,
     max_pholders = 32,
     max_spec_len = SHRT_MAX,
@@ -48,9 +58,9 @@ enum {
 };
 
 struct subproc_segment {
-    ofp_atom_t atom;
+    enum ofp_atom atom;
     union {
-        ofmt_resolver_t resolver;
+        ofmt_resolver_callback resolver;
         struct {
             short begin, len;
         } buf_idx;
@@ -63,13 +73,12 @@ struct subproc_segment {
 struct subproc {
     struct subproc_segment segments[max_segments];
     const char *argv[max_argv_len];
-    int argvwrite;
     short segwrite;
     bool pipe_enabled;
 };
 
 struct print_pholder {
-    ofmt_resolver_t resolver;
+    ofmt_resolver_callback resolver;
     short iovidx;
 };
 
@@ -81,14 +90,14 @@ struct print {
 };
 
 struct ofmt {
-    ofmt_mode_t mode;
+    enum ofmt_mode mode;
     void *opaque;
     void (*opaque_free)(void*);
-    radix_t *resolvers_map;
-    ofmt_resolver_t pipe_resolver;
+    struct radix *resolvers_map;
+    ofmt_resolver_callback pipe_resolver;
 
     struct ofp_setup ofp_setup;
-    ofmt_err_t error;
+    struct ofmt_err error;
 
     char *buffer;
     int buflen;
@@ -100,7 +109,7 @@ struct ofmt {
     };
 };
 
-static int fail(ofmt_t *ofmt, ofmt_fail_t why)
+static int fail(struct ofmt *ofmt, enum ofmt_fail why)
 {
     assert(why != ofmt_fail_bad_state);
     ofmt->error.reason = why;
@@ -109,9 +118,9 @@ static int fail(ofmt_t *ofmt, ofmt_fail_t why)
     return -1;
 }
 
-static int get_resolver(ofmt_t *ofmt,
-                        const ofp_token_t *tok,
-                        ofmt_resolver_t *res)
+static int get_resolver(struct ofmt *ofmt,
+                        const struct ofp_token *tok,
+                        ofmt_resolver_callback *res)
 {
     if (tok->atom != ofp_atom_pholder)
         return fail(ofmt, ofmt_fail_bad_state);
@@ -137,10 +146,10 @@ static int get_resolver(ofmt_t *ofmt,
     return n + 1;
 }
 
-static int print_save_pholder(ofmt_t *ofmt, const ofp_token_t *tok)
+static int print_save_pholder(struct ofmt *ofmt, const struct ofp_token *tok)
 {
     struct print *print;
-    ofmt_resolver_t resolver;
+    ofmt_resolver_callback resolver;
     int used;
 
     if (tok->len < 1)   /* broken parser? */
@@ -194,7 +203,7 @@ static size_t copy_escaped(char *dst, const char *src, size_t len)
     return j;
 }
 
-static int store(ofmt_t *ofmt, const char *begin, size_t len)
+static int store(struct ofmt *ofmt, const char *begin, size_t len)
 {
     if (ofmt->buflen - ofmt->bufwrite < len) {
         /* it should be enough by construction, if it isn't it means the
@@ -208,9 +217,9 @@ static int store(ofmt_t *ofmt, const char *begin, size_t len)
     return 0;
 }
 
-static void record_fail(void *o, ofp_fail_t reason)
+static void record_fail(void *o, enum ofp_fail reason)
 {
-    ofmt_t *ofmt = o;
+    struct ofmt *ofmt = o;
 
     /* we returned -1 during *_emit, so we already failed */
     if (reason == ofp_fail_emitting)
@@ -234,9 +243,9 @@ static inline struct subproc_segment *cur_segment(struct subproc *subproc)
     return &subproc->segments[subproc->segwrite - 1];
 }
 
-static int subproc_merge_verbatim(ofmt_t *ofmt,
+static int subproc_merge_verbatim(struct ofmt *ofmt,
                                   struct subproc_segment *s,
-                                  const ofp_token_t *tok)
+                                  const struct ofp_token *tok)
 {
     int w;
 
@@ -248,7 +257,8 @@ static int subproc_merge_verbatim(ofmt_t *ofmt,
     return 0;
 }
 
-static int subproc_save_verbatim(ofmt_t *ofmt, const ofp_token_t *tok)
+static int subproc_save_verbatim(struct ofmt *ofmt,
+                                 const struct ofp_token *tok)
 {
     struct subproc_segment *s;
     int w;
@@ -283,10 +293,11 @@ static int subproc_save_verbatim(ofmt_t *ofmt, const ofp_token_t *tok)
     return 0;
 }
 
-static int subproc_save_pholder(ofmt_t *ofmt, const ofp_token_t *tok)
+static int subproc_save_pholder(struct ofmt *ofmt,
+                                const struct ofp_token *tok)
 {
     struct subproc_segment *s;
-    ofmt_resolver_t resolver;
+    ofmt_resolver_callback resolver;
     int used;
 
     if (tok->len < 1)   /* broken parser? */
@@ -307,7 +318,7 @@ static int subproc_save_pholder(ofmt_t *ofmt, const ofp_token_t *tok)
     return used;
 }
 
-static int subproc_save_whitespace(ofmt_t *ofmt)
+static int subproc_save_whitespace(struct ofmt *ofmt)
 {
     struct subproc_segment *s;
 
@@ -333,9 +344,9 @@ static int subproc_save_whitespace(ofmt_t *ofmt)
     return 0;
 }
 
-static int subproc_emit(void *o, const ofp_token_t *tok)
+static int subproc_emit(void *o, const struct ofp_token *tok)
 {
-    ofmt_t *ofmt = o;
+    struct ofmt *ofmt = o;
 
     switch (tok->atom) {
     case ofp_atom_pholder:
@@ -351,7 +362,7 @@ static int subproc_emit(void *o, const ofp_token_t *tok)
     return 0;
 }
 
-static int print_save_verbatim(ofmt_t *ofmt, const ofp_token_t *tok)
+static int print_save_verbatim(struct ofmt *ofmt, const struct ofp_token *tok)
 {
     int start;
     struct print *print;
@@ -374,7 +385,7 @@ static int print_save_verbatim(ofmt_t *ofmt, const ofp_token_t *tok)
     return 0;
 }
 
-static int subproc_post_scan(ofmt_t *ofmt)
+static int subproc_post_scan(struct ofmt *ofmt)
 {
     struct subproc *subproc;
     int arg_idx;
@@ -411,9 +422,9 @@ static int subproc_post_scan(ofmt_t *ofmt)
     return 0;
 }
 
-static int print_emit(void *o, const ofp_token_t *tok)
+static int print_emit(void *o, const struct ofp_token *tok)
 {
-    ofmt_t *ofmt = o;
+    struct ofmt *ofmt = o;
 
     switch (tok->atom) {
     case ofp_atom_pholder:
@@ -427,7 +438,7 @@ static int print_emit(void *o, const ofp_token_t *tok)
     return 0;
 }
 
-static int ensure_buffer(ofmt_t *ofmt, size_t speclen)
+static int ensure_buffer(struct ofmt *ofmt, size_t speclen)
 {
     size_t needed;
     char *new_buffer;
@@ -462,7 +473,8 @@ static int ensure_buffer(ofmt_t *ofmt, size_t speclen)
     return 0;
 }
 
-static int print_eval(ofmt_t *ofmt, const ofmt_evaluate_params_t *params)
+static int print_eval(struct ofmt *ofmt,
+                      const struct ofmt_evaluate_params *params)
 {
     struct print *print = &ofmt->print;
 
@@ -486,7 +498,7 @@ static int print_eval(ofmt_t *ofmt, const ofmt_evaluate_params_t *params)
     return 0;
 }
 
-static int dry_run(const launcher_run_t *lch)
+static int dry_run(const struct launcher_run *lch)
 {
     char buffer[60];
 
@@ -510,7 +522,7 @@ static int dry_run(const launcher_run_t *lch)
     return 0;   /* of course */
 }
 
-static int launch(ofmt_t *ofmt, const launcher_run_t *lch)
+static int launch(struct ofmt *ofmt, const struct launcher_run *lch)
 {
     int status;
 
@@ -526,7 +538,8 @@ static int launch(ofmt_t *ofmt, const launcher_run_t *lch)
     return -1;
 }
 
-static int subproc_eval(ofmt_t *ofmt, const ofmt_evaluate_params_t *params)
+static int subproc_eval(struct ofmt *ofmt,
+                        const struct ofmt_evaluate_params *params)
 {
     struct subproc *subproc = &ofmt->subproc;
     char const **argv = subproc->argv;
@@ -584,7 +597,7 @@ static int subproc_eval(ofmt_t *ofmt, const ofmt_evaluate_params_t *params)
         input_stdin = ofmt->pipe_resolver(params->item, ofmt->opaque);
     }
 
-    const launcher_run_t run = {
+    const struct launcher_run run = {
         .argv = argv,
         .chdir_to = params->opt_subproc_chdir,
         .input.bytes = (void *)input_stdin,
@@ -596,10 +609,10 @@ static int subproc_eval(ofmt_t *ofmt, const ofmt_evaluate_params_t *params)
         : launch(ofmt, &run);
 }
 
-ofmt_t *ofmt_new(void)
+struct ofmt *ofmt_new(void)
 {
-    ofmt_t *ofmt;
-    radix_t *resolvers_map;
+    struct ofmt *ofmt;
+    struct radix *resolvers_map;
 
     ofmt = malloc(sizeof(struct ofmt));
     if (!ofmt) {
@@ -623,25 +636,29 @@ ofmt_t *ofmt_new(void)
     return ofmt;
 }
 
-static void free_opaque(ofmt_t *ofmt)
+static void free_opaque(struct ofmt *ofmt)
 {
     if (ofmt->opaque && ofmt->opaque_free)
         ofmt->opaque_free(ofmt->opaque);
 }
 
-void ofmt_set_opaque(ofmt_t *ofmt, void *opaque, void (*opaque_free)(void *))
+void ofmt_set_opaque(struct ofmt *ofmt,
+                     void *opaque,
+                     void (*opaque_free)(void *))
 {
     free_opaque(ofmt);
     ofmt->opaque = opaque;
     ofmt->opaque_free = opaque_free;
 }
 
-void *ofmt_get_opaque(const ofmt_t *ofmt)
+void *ofmt_get_opaque(const struct ofmt *ofmt)
 {
     return ofmt->opaque;
 }
 
-int ofmt_set_resolver(ofmt_t *ofmt, const char *key, ofmt_resolver_t resolver)
+int ofmt_set_resolver(struct ofmt *ofmt,
+                      const char *key,
+                      ofmt_resolver_callback resolver)
 {
     if (radix_register(ofmt->resolvers_map, key, resolver) == -1)
         return fail(ofmt, errno == EINVAL ? ofmt_fail_bad_setup : ofmt_fail_system);
@@ -649,15 +666,15 @@ int ofmt_set_resolver(ofmt_t *ofmt, const char *key, ofmt_resolver_t resolver)
     return 0;
 }
 
-int ofmt_set_pipe_resolver(ofmt_t *ofmt, ofmt_resolver_t resolver)
+int ofmt_set_pipe_resolver(struct ofmt *ofmt, ofmt_resolver_callback resolver)
 {
     ofmt->pipe_resolver = resolver;
     return 0;
 }
 
-static void reset(ofmt_t *ofmt, ofmt_mode_t mode)
+static void reset(struct ofmt *ofmt, enum ofmt_mode mode)
 {
-    ofmt->error = (ofmt_err_t){};
+    ofmt->error = (struct ofmt_err){};
     ofmt->bufwrite = 0;
 
     switch (mode) {
@@ -680,8 +697,10 @@ static void reset(ofmt_t *ofmt, ofmt_mode_t mode)
     }
 }
 
-int ofmt_compile(ofmt_t *ofmt, ofmt_mode_t mode,
-                 const char *spec, size_t speclen)
+int ofmt_compile(struct ofmt *ofmt,
+                 enum ofmt_mode mode,
+                 const char *spec,
+                 size_t speclen)
 {
     reset(ofmt, mode);
 
@@ -702,7 +721,7 @@ int ofmt_compile(ofmt_t *ofmt, ofmt_mode_t mode,
     return 0;
 }
 
-int ofmt_evaluate(ofmt_t *ofmt, const ofmt_evaluate_params_t *params)
+int ofmt_evaluate(struct ofmt *ofmt, const struct ofmt_evaluate_params *params)
 {
     switch (ofmt->mode) {
     case ofmt_mode_exec:
@@ -714,7 +733,7 @@ int ofmt_evaluate(ofmt_t *ofmt, const ofmt_evaluate_params_t *params)
     }
 }
 
-const char * ofmt_fail_str(ofmt_fail_t f)
+const char * ofmt_fail_str(enum ofmt_fail f)
 {
     static const char * const repr[] = {
         [ofmt_fail_none]                    = "ofmt_fail_none",
@@ -733,12 +752,12 @@ const char * ofmt_fail_str(ofmt_fail_t f)
     return repr[f];
 }
 
-const ofmt_err_t * ofmt_get_error(const ofmt_t *ofmt)
+const struct ofmt_err * ofmt_get_error(const struct ofmt *ofmt)
 {
     return &ofmt->error;
 }
 
-void ofmt_print_error(const ofmt_t *ofmt)
+void ofmt_print_error(const struct ofmt *ofmt)
 {
     switch (ofmt->error.reason) {
     case ofmt_fail_parse:
@@ -765,7 +784,7 @@ void ofmt_print_error(const ofmt_t *ofmt)
     }
 }
 
-void ofmt_del(ofmt_t *ofmt)
+void ofmt_del(struct ofmt *ofmt)
 {
     if (!ofmt)
         return;
