@@ -26,15 +26,15 @@
 #include <stdbool.h>
 #include <stdlib.h>
 
-typedef enum {
+enum symbol_class {
     symbol_class_invalid = -1,
     symbol_class_escape,
     symbol_class_pholder,
     symbol_class_verbatim,
     symbol_class_whitespace,
-} symbol_class_t;
+};
 
-static symbol_class_t get_symbol_class(char c)
+static enum symbol_class get_symbol_class(char c)
 {
     switch (c) {
     case '\\':
@@ -42,13 +42,13 @@ static symbol_class_t get_symbol_class(char c)
     case '%':
         return symbol_class_pholder;
     default:
-        return isspace(c)
+        return isspace((unsigned char)c)
             ? symbol_class_whitespace
             : symbol_class_verbatim;
     }
 }
 
-static ofp_atom_t atom_of(symbol_class_t sycl)
+static enum ofp_atom atom_of(enum symbol_class sycl)
 {
     switch (sycl) {
     case symbol_class_escape:
@@ -65,15 +65,15 @@ static ofp_atom_t atom_of(symbol_class_t sycl)
     abort();
 }
 
-static inline int fail(ofp_setup_t ofps, ofp_fail_t how)
+static inline int fail(const struct ofp_setup *ofps, enum ofp_fail how)
 {
     assert(how != ofp_fail_bad_state);   /* algorithm is buggy */
     ofps->fail(ofps->opaque, how);
     return -1;
 }
 
-static inline int try_emit(ofp_setup_t ofps,
-                           ofp_atom_t atom,
+static inline int try_emit(const struct ofp_setup *ofps,
+                           enum ofp_atom atom,
                            const char *begin,
                            size_t len)
 {
@@ -86,7 +86,7 @@ static inline int try_emit(ofp_setup_t ofps,
 
     int ans = ofps->emit(
         ofps->opaque,
-        &(ofp_token_t){
+        &(struct ofp_token){
             .atom = atom,
             .begin = begin,
             .len = len,
@@ -99,7 +99,7 @@ static inline int try_emit(ofp_setup_t ofps,
     return ans;
 }
 
-const char * ofp_atom_str(ofp_atom_t a)
+const char * ofp_atom_str(enum ofp_atom a)
 {
     static const char * const repr[] = {
         "ofp_atom_pholder",
@@ -109,7 +109,7 @@ const char * ofp_atom_str(ofp_atom_t a)
     return repr[a];
 }
 
-const char * ofp_fail_str(ofp_fail_t f)
+const char * ofp_fail_str(enum ofp_fail f)
 {
     static const char * const repr[] = {
         [ofp_fail_none]                 = "ofp_fail_none",
@@ -122,16 +122,16 @@ const char * ofp_fail_str(ofp_fail_t f)
     return repr[f];
 }
 
-int ofp_scan(ofp_setup_t ofps, const char *spec, size_t speclen)
+int ofp_scan(const struct ofp_setup *ofps, const char *spec, size_t speclen)
 {
     if (speclen == 0 || speclen > INT_MAX)
         return fail(ofps, ofp_fail_bad_spec);
 
     int escaped = 0;
     const char *begin = NULL;
-    ofp_atom_t atom;
+    enum ofp_atom atom = ofp_atom_verbatim;
 
-    static const symbol_class_t stay_if[] = {
+    static const enum symbol_class stay_if[] = {
         [ofp_atom_pholder]    = symbol_class_verbatim,
         [ofp_atom_verbatim]   = symbol_class_verbatim,
         [ofp_atom_whitespace] = symbol_class_whitespace,
@@ -149,7 +149,7 @@ int ofp_scan(ofp_setup_t ofps, const char *spec, size_t speclen)
             /* continuing for a last 'emit' with what is left,
              * possibly with a rewind. */
         } else {
-            symbol_class_t sycl;
+            enum symbol_class sycl;
 
             if (escaped) {
                 --escaped;
