@@ -22,21 +22,21 @@
 
 #include <stddef.h>
 
-typedef enum {
+enum ofp_atom {
     ofp_atom_pholder,
     ofp_atom_verbatim,
     ofp_atom_whitespace,
-} ofp_atom_t;
+};
 
-typedef struct {
+struct ofp_token {
     const char *begin;
     size_t len;
-    ofp_atom_t atom;
-} ofp_token_t;
+    enum ofp_atom atom;
+};
 
-const char * ofp_atom_str(ofp_atom_t);
+const char * ofp_atom_str(enum ofp_atom);
 
-typedef enum {
+enum ofp_fail {
     ofp_fail_none = 0,
 
     ofp_fail_bad_spec,
@@ -44,16 +44,14 @@ typedef enum {
     ofp_fail_emitting,
     ofp_fail_invalid_pholder,
     ofp_fail_trail_escape,
-} ofp_fail_t;
+};
 
-const char * ofp_fail_str(ofp_fail_t);
+const char * ofp_fail_str(enum ofp_fail);
 
 struct ofp_setup {
     void *opaque;
-    int (*emit)(void *, const ofp_token_t *);
-    void (*fail)(void *, ofp_fail_t);
+    int (*emit)(void *, const struct ofp_token *);
+    void (*fail)(void *, enum ofp_fail);
 };
 
-typedef const struct ofp_setup * ofp_setup_t;
-
-int ofp_scan(ofp_setup_t, const char *spec, size_t speclen);
+int ofp_scan(const struct ofp_setup *, const char *spec, size_t speclen);
