@@ -19,13 +19,12 @@
  */
 #pragma once
 
-typedef struct persist_dir persist_dir_t;
-typedef struct persist_file persist_file_t;
+struct persist_dir;
 
-persist_dir_t *persist_dir_new(int basedir);
+struct persist_dir *persist_dir_new(int basedir);
 
-persist_file_t *persist_dir_iter(persist_dir_t *, void **aux);
+struct persist_file *persist_dir_iter(struct persist_dir *, void **aux);
 
-int persist_dir_fd(const persist_dir_t *);
+int persist_dir_fd(const struct persist_dir *);
 
-void persist_dir_del(persist_dir_t *);
+void persist_dir_del(struct persist_dir *);
