@@ -30,12 +30,12 @@
 #include <mrss.h>
 
 struct state {
-    placeholder_extra_t extra;
+    struct placeholder_extra extra;
     int buflen;
     char bytes[];
 };
 
-typedef struct state state_t;
+struct state;
 
 #define RESOLVE_ITEM_STR(field) \
     static const char * resolve_ ## field (void *item, void *opaque)    \
@@ -68,7 +68,7 @@ RESOLVE_ITEM_STR(description);
 #define RESOLVE_ITEM_INT(field) \
     static const char * resolve_ ## field (void *item, void *opaque)    \
     {                                                                   \
-        state_t *state = opaque;                                        \
+        struct state *state = opaque;                                   \
         int n;                                                          \
                                                                         \
         n = snprintf(state->bytes, state->buflen, "%d",                 \
@@ -85,7 +85,7 @@ RESOLVE_ITEM_INT(enclosure_length);
 
 static const char * resolve_incremental_id(void *item, void *opaque)
 {
-    state_t *state = opaque;
+    struct state *state = opaque;
     int n;
 
     n = snprintf(state->bytes, state->buflen, "%06u",
@@ -100,17 +100,17 @@ static const char * resolve_incremental_id(void *item, void *opaque)
 #define RESOLVE_FEED_ITEM_STR(field) \
     static const char * resolve_ ## field (void *item, void *opaque)    \
     {                                                                   \
-        state_t *state = opaque;                                        \
+        struct state *state = opaque;                                   \
         return state->extra.field;                                      \
     }
 
 RESOLVE_FEED_ITEM_STR(feed_title);
 RESOLVE_FEED_ITEM_STR(feed_identifier);
 
-int placeholders_setup(ofmt_t *ofmt)
+int placeholders_setup(struct ofmt *ofmt)
 {
     int buflen;
-    state_t *state;
+    struct state *state;
 
     buflen = 1 + snprintf(NULL, 0, "%d", INT_MAX);
 
@@ -119,7 +119,7 @@ int placeholders_setup(ofmt_t *ofmt)
         warn("malloc");
         return -1;
     }
-    *state = (state_t){ .buflen = buflen };
+    *state = (struct state){ .buflen = buflen };
     ofmt_set_opaque(ofmt, state, free);
 
     #define PLACEHOLDER(key, field, ...) \
@@ -139,9 +139,10 @@ fail:
     return -1;
 }
 
-void placeholders_set_extra(const ofmt_t *ofmt, const placeholder_extra_t *extra)
+void placeholders_set_extra(const struct ofmt *ofmt,
+                            const struct placeholder_extra *extra)
 {
-    state_t *state = ofmt_get_opaque(ofmt);
+    struct state *state = ofmt_get_opaque(ofmt);
     if (!state)
         panic("placeholders_set_extra used before placeholders_setup?");
 
