@@ -22,16 +22,17 @@
 
 #include "outfmt.h"
 
-int placeholders_setup(ofmt_t *);
+int placeholders_setup(struct ofmt *);
 
 /* This struct collects additional information that gets copied in the
- * opaque structure within a ofmt_t object.  This information is
+ * opaque structure within a ofmt object.  This information is
  * ultimately available to the placeholder resolution functions
  * defined in 'placeholders.c'. */
-typedef struct {
+struct placeholder_extra {
     unsigned incremental_id;
     const char *feed_title;
     const char *feed_identifier;
-} placeholder_extra_t;
+};
 
-void placeholders_set_extra(const ofmt_t *, const placeholder_extra_t *);
+void placeholders_set_extra(const struct ofmt *,
+                            const struct placeholder_extra *);
