@@ -20,12 +20,15 @@
 
 #pragma once
 
-typedef struct radix radix_t;
+struct radix;
 
-radix_t *radix_new(void);
+struct radix *radix_new(void);
 
-int radix_register(radix_t *, const char *path, void *item);
+int radix_register(struct radix *, const char *path, void *item);
 
-int radix_lookup(const radix_t *, const char *path, int pathlen, void **found);
+int radix_lookup(const struct radix *,
+                 const char *path,
+                 int pathlen,
+                 void **found);
 
-void radix_del(radix_t *);
+void radix_del(struct radix *);
