@@ -23,20 +23,20 @@
 #include <stdbool.h>
 #include <stddef.h>
 
-typedef struct rc rc_t;
+struct rc;
 
-typedef struct {
+struct rc_global {
     unsigned short jobs;
     const char *persist_dir;
-} rc_global_t;
+};
 
-typedef enum {
+enum rc_handler {
     rc_hdl_print,
     rc_hdl_exec,
     rc_hdl_pipe,
-} rc_handler_t;
+};
 
-typedef struct {
+struct rc_feed {
     const char *name;
     const char *url;
     struct {
@@ -44,21 +44,21 @@ typedef struct {
         size_t len;
     } ofmt;
     const char *chdir;
-    rc_handler_t handler;
-} rc_feed_t;
+    enum rc_handler handler;
+};
 
-rc_t *rc_new(void);
+struct rc *rc_new(void);
 
-int rc_parse_buffer(rc_t *, const char *str, size_t len);
+int rc_parse_buffer(struct rc *, const char *str, size_t len);
 
-int rc_load(rc_t *);
+int rc_load(struct rc *);
 
-const rc_global_t * rc_get_global(const rc_t *);
+const struct rc_global * rc_get_global(const struct rc *);
 
-const rc_feed_t * rc_get_feed(const rc_t *, unsigned idx);
+const struct rc_feed * rc_get_feed(const struct rc *, unsigned idx);
 
-unsigned rc_n_feeds(const rc_t *);
+unsigned rc_n_feeds(const struct rc *);
 
-void rc_dump(const rc_t *);
+void rc_dump(const struct rc *);
 
-void rc_free(rc_t *);
+void rc_free(struct rc *);
