@@ -29,11 +29,11 @@
 #include <time.h>
 #include <unistd.h>
 
-typedef enum {
+enum aux_mode {
     mode_none,
     mode_count,
     mode_sleep,
-} aux_mode_t;
+};
 
 static const char * const aux_mode_str[] = {
     "mode_none",
@@ -109,7 +109,7 @@ static int run_sleep(const char *arg)
 int main(int argc, char **argv)
 {
     int opt, verbose = 0;
-    aux_mode_t mode = mode_none;
+    enum aux_mode mode = mode_none;
     const char *mode_arg = NULL;
 
     while (errno = 0, opt = getopt(argc, argv, "c:hs:v"), opt != -1) {
