@@ -37,12 +37,12 @@
 #define INFO(...)
 #endif
 
-static int launcher_base(util_ctx_t ctx, intptr_t opaque)
+static int launcher_base(struct util_ctx *ctx, intptr_t opaque)
 {
     const char *cmd_true[] = {"true", NULL};
     const char *cmd_false[] = {"false", NULL};
-    const launcher_run_t run_true = { .argv = cmd_true };
-    const launcher_run_t run_false = { .argv = cmd_false };
+    const struct launcher_run run_true = { .argv = cmd_true };
+    const struct launcher_run run_false = { .argv = cmd_false };
 
     int status;
 
@@ -60,14 +60,14 @@ static int launcher_base(util_ctx_t ctx, intptr_t opaque)
     return 0;
 }
 
-static int launcher_pipe_regular(util_ctx_t ctx, intptr_t opaque)
+static int launcher_pipe_regular(struct util_ctx *ctx, intptr_t opaque)
 {
     const char *cmd[] = {"./aux_test_launcher", "-cast", NULL};
     const char text[] = "carasta\ncarasta\n";
     int status;
 
     EXPECT(launcher_execvp(
-        &(launcher_run_t){
+        &(struct launcher_run){
             .argv = cmd,
             .input.bytes = (void *)text,
             .input.len = sizeof(text) - 1,
@@ -79,7 +79,7 @@ static int launcher_pipe_regular(util_ctx_t ctx, intptr_t opaque)
     return 0;
 }
 
-static int launcher_pipe_long(util_ctx_t ctx, intptr_t opaque)
+static int launcher_pipe_long(struct util_ctx *ctx, intptr_t opaque)
 {
     enum {
         bufsize = 4096 * 2000,  /* hopefully more than pipe buffer: we want to
@@ -95,7 +95,7 @@ static int launcher_pipe_long(util_ctx_t ctx, intptr_t opaque)
     memset(buffer, 0, bufsize);
 
     EXPECT(launcher_execvp(
-        &(launcher_run_t){
+        &(struct launcher_run){
             .argv = cmd,
             .input.bytes = (void *)buffer,
             .input.len = bufsize,
