@@ -53,7 +53,7 @@ struct test_params {
 };
 
 struct test_setup {
-    ofmt_t *ofmt;
+    struct ofmt *ofmt;
     int pipe_r, pipe_w;
 
     const char *resolved_pipe;
@@ -100,11 +100,11 @@ static const char * resolve_xn(void *item, void *opaque)
     return ts->resolved_xn;
 }
 
-static int test_reject_unresolved(util_ctx_t ctx, intptr_t opaque)
+static int test_reject_unresolved(struct util_ctx *ctx, intptr_t opaque)
 {
-    ofmt_t *ofmt;
+    struct ofmt *ofmt;
 
-    ofmt_mode_t mode = (ofmt_mode_t)opaque;
+    enum ofmt_mode mode = (enum ofmt_mode)opaque;
 
     /* Note: %x is not a placeholder, as it is escpaed */
     const char spec[] = "hello \\%x %t world %a\\n";
@@ -161,7 +161,7 @@ static void teardown(struct test_setup *tsetup)
     ofmt_del(tsetup->ofmt);
 }
 
-static int setup(struct test_setup *out_ts, ofmt_mode_t mode)
+static int setup(struct test_setup *out_ts, enum ofmt_mode mode)
 {
     struct test_setup ts = {
         .pipe_r      = -1,
@@ -214,17 +214,17 @@ fail:
 
 static int evaluate(const struct test_setup *ts)
 {
-    return ofmt_evaluate(ts->ofmt, &(const ofmt_evaluate_params_t){
+    return ofmt_evaluate(ts->ofmt, &(const struct ofmt_evaluate_params){
         .item = (void *)ts,
         .opt_print_fd = &ts->pipe_w,
     });
 }
 
-static int test_mode_print(util_ctx_t ctx, intptr_t opaque)
+static int test_mode_print(struct util_ctx *ctx, intptr_t opaque)
 {
     const struct test_params *tp = (const struct test_params *)opaque;
     struct test_setup ts;
-    ofmt_mode_t mode = ofmt_mode_print;
+    enum ofmt_mode mode = ofmt_mode_print;
 
     EXPECT(setup(&ts, mode) == 0);
 
@@ -253,11 +253,11 @@ static int run(const struct test_setup *ts)
     return 0;
 }
 
-static int test_mode_subprocess(util_ctx_t ctx, intptr_t opaque)
+static int test_mode_subprocess(struct util_ctx *ctx, intptr_t opaque)
 {
     const struct test_params *tp = (const struct test_params *)opaque;
     struct test_setup ts;
-    ofmt_mode_t mode = ofmt_mode_exec;
+    enum ofmt_mode mode = ofmt_mode_exec;
 
     EXPECT(setup(&ts, mode) == 0);
 
@@ -270,7 +270,7 @@ static int test_mode_subprocess(util_ctx_t ctx, intptr_t opaque)
 
 /* This test verifies the existence of a proper boundary for the amount of
  * segments used for subprocess launching ('max_segments'). */
-static int test_limits_subprocess_1(util_ctx_t ctx, intptr_t opaque)
+static int test_limits_subprocess_1(struct util_ctx *ctx, intptr_t opaque)
 {
     enum {
         /* the value of this constant must match the value
@@ -292,7 +292,7 @@ static int test_limits_subprocess_1(util_ctx_t ctx, intptr_t opaque)
         input[i + 1] = '0' + (i % 10);
     }
 
-    ofmt_mode_t mode = ofmt_mode_exec;
+    enum ofmt_mode mode = ofmt_mode_exec;
 
     EXPECT(setup(&ts, mode) == 0);
 
@@ -334,9 +334,9 @@ static int test_limits_subprocess_1(util_ctx_t ctx, intptr_t opaque)
 
 /* This test exercies the boundary checking for the maximum evaluation
  * buffer ('max_eval_buflen'). */
-static int test_limits_subprocess_2(util_ctx_t ctx, intptr_t opaque)
+static int test_limits_subprocess_2(struct util_ctx *ctx, intptr_t opaque)
 {
-    ofmt_mode_t mode = ofmt_mode_exec;
+    enum ofmt_mode mode = ofmt_mode_exec;
 
     /* the value of this constant must match the value of
      * the corresponding one in outfmt.c, otherwise the test
@@ -374,11 +374,11 @@ static int test_limits_subprocess_2(util_ctx_t ctx, intptr_t opaque)
     return 0;
 }
 
-static int test_pipe_resolver(util_ctx_t ctx, intptr_t opaque)
+static int test_pipe_resolver(struct util_ctx *ctx, intptr_t opaque)
 {
     struct test_setup ts;
-    const ofmt_err_t *e;
-    ofmt_mode_t mode = ofmt_mode_pipe;
+    const struct ofmt_err *e;
+    enum ofmt_mode mode = ofmt_mode_pipe;
 
     EXPECT(setup(&ts, mode) == 0);
     EXPECT(ofmt_set_pipe_resolver(ts.ofmt, resolve_pipe) == 0);
