@@ -30,9 +30,9 @@
 #define DEBUG(...) warnx(__VA_ARGS__);
 #endif
 
-static int test_create(util_ctx_t ctx, intptr_t opaque)
+static int test_create(struct util_ctx *ctx, intptr_t opaque)
 {
-    radix_t *r;
+    struct radix *r;
     const char key[] = "senap";
     size_t keylen = sizeof key - 1;
     void *item = NULL;
@@ -47,7 +47,7 @@ static int test_create(util_ctx_t ctx, intptr_t opaque)
     return 0;
 }
 
-static int test_multi(util_ctx_t ctx, intptr_t opaque)
+static int test_multi(struct util_ctx *ctx, intptr_t opaque)
 {
     static const char *sequence[] = {
         "c",    /* new in root */
@@ -76,7 +76,7 @@ static int test_multi(util_ctx_t ctx, intptr_t opaque)
         {NULL,      0},
     };
 
-    radix_t *r;
+    struct radix *r;
 
     EXPECT(r = radix_new());
 
@@ -107,9 +107,9 @@ static int test_multi(util_ctx_t ctx, intptr_t opaque)
     return 0;
 }
 
-static int test_corner(util_ctx_t ctx, intptr_t opaque)
+static int test_corner(struct util_ctx *ctx, intptr_t opaque)
 {
-    radix_t *r;
+    struct radix *r;
 
     EXPECT(r = radix_new());
     EXPECT(radix_register(r, "", NULL) == -1 && errno == EINVAL);
