@@ -31,7 +31,7 @@
 #include "test_counters.h"
 #include "unittest.h"
 
-static int mksavefile(util_ctx_t ctx, savefile_t **sf)
+static int mksavefile(struct util_ctx *ctx, struct savefile **sf)
 {
     int d;
 
@@ -42,10 +42,10 @@ static int mksavefile(util_ctx_t ctx, savefile_t **sf)
     return 0;
 }
 
-static int savefile_base(util_ctx_t ctx, intptr_t opaque)
+static int savefile_base(struct util_ctx *ctx, intptr_t opaque)
 {
-    savefile_t *sf;
-    feed_t *f1, *f2;
+    struct savefile *sf;
+    struct feed *f1, *f2;
 
     EXPECT(mksavefile(ctx, &sf) == 0);
     EXPECT(f1 = savefile_get_feed(sf, __func__));
@@ -57,7 +57,7 @@ static int savefile_base(util_ctx_t ctx, intptr_t opaque)
     return 0;
 }
 
-static int loop_entries(util_ctx_t ctx, intptr_t opaque)
+static int loop_entries(struct util_ctx *ctx, intptr_t opaque)
 {
     /* Insert a collection of items, save, open again, and verify that all
      * the items are stored.  Piggybacks a check for correct storage of
@@ -70,9 +70,9 @@ static int loop_entries(util_ctx_t ctx, intptr_t opaque)
         items_count = 42,
     };
 
-    savefile_t *sf;
-    feed_t *f;
-    str_t items[n_items];
+    struct savefile *sf;
+    struct feed *f;
+    struct str items[n_items];
 
     EXPECT(mksavefile(ctx, &sf) == 0);
 
@@ -82,7 +82,7 @@ static int loop_entries(util_ctx_t ctx, intptr_t opaque)
         items[i] = STR_DEFINE("item_id");
 
     EXPECT(feed_set_items(f,
-        &(feed_items_t){
+        &(struct feed_items){
             .items = items,
             .n_items = n_items
         }
@@ -112,7 +112,7 @@ static int loop_entries(util_ctx_t ctx, intptr_t opaque)
 
     aux = NULL;
     while (f = savefile_iter_feeds(sf, &aux), f) {
-        feed_items_t items = feed_get_items(f);
+        struct feed_items items = feed_get_items(f);
 
         for (unsigned i = 0; i < items.n_items; ++i) {
             EXPECT(items.items[i].len == strlen("item_id"));
@@ -135,7 +135,7 @@ static int loop_entries(util_ctx_t ctx, intptr_t opaque)
     return 0;
 }
 
-static int prepare_scenario(util_ctx_t ctx, savefile_t **sf)
+static int prepare_scenario(struct util_ctx *ctx, struct savefile **sf)
 {
     int tmpdir, fd;
 
@@ -161,7 +161,7 @@ static int prepare_scenario(util_ctx_t ctx, savefile_t **sf)
     return 0;
 }
 
-static int count_listed(const savefile_t *sf)
+static int count_listed(const struct savefile *sf)
 {
     int listed = 0;
 
@@ -170,12 +170,12 @@ static int count_listed(const savefile_t *sf)
     return listed;
 }
 
-static int untouchable_files_skipped(util_ctx_t ctx, intptr_t opaque)
+static int untouchable_files_skipped(struct util_ctx *ctx, intptr_t opaque)
 {
     /* Making sure that files which are unrecognized, or recognized to be
      * incompatible, will not be presented during iteration. */
 
-    savefile_t *sf;
+    struct savefile *sf;
 
     EXPECT(prepare_scenario(ctx, &sf) == 0);
 
@@ -191,12 +191,12 @@ static int untouchable_files_skipped(util_ctx_t ctx, intptr_t opaque)
     return 0;
 }
 
-static int untouchable_files_not_usable(util_ctx_t ctx, intptr_t opaque)
+static int untouchable_files_not_usable(struct util_ctx *ctx, intptr_t opaque)
 {
     /* Making sure that files which are unrecognized, or recognized to be
      * incompatible, can not be handled even if explicitly loaded. */
 
-    savefile_t *sf;
+    struct savefile *sf;
 
     EXPECT(prepare_scenario(ctx, &sf) == 0);
 
@@ -214,7 +214,7 @@ static int untouchable_files_not_usable(util_ctx_t ctx, intptr_t opaque)
     return 0;
 }
 
-static int corrupt_savefile(util_ctx_t ctx, const char *filename)
+static int corrupt_savefile(struct util_ctx *ctx, const char *filename)
 {
     int d, f;
     struct stat statbuf;
@@ -234,13 +234,13 @@ static int corrupt_savefile(util_ctx_t ctx, const char *filename)
     return 0;
 }
 
-static int corruption_test(util_ctx_t ctx, intptr_t opaque)
+static int corruption_test(struct util_ctx *ctx, intptr_t opaque)
 {
     /* Making sure that a recognized and compatbile file which happens to
      * be corrupt cannot be loaded, but will be written over. */
 
-    savefile_t *sf;
-    feed_t *f;
+    struct savefile *sf;
+    struct feed *f;
 
     EXPECT(mksavefile(ctx, &sf) == 0);
     EXPECT(f = savefile_get_feed(sf, "hello"));
@@ -277,13 +277,13 @@ static int corruption_test(util_ctx_t ctx, intptr_t opaque)
     return 0;
 }
 
-static int add_scan_add_scan(util_ctx_t ctx, intptr_t opaque)
+static int add_scan_add_scan(struct util_ctx *ctx, intptr_t opaque)
 {
     /* Ensure that feeds are stored uniquely in a savefile, and that
      * alternating scans and additions do not result in repeated entries */
 
-    savefile_t *sf;
-    feed_t *f;
+    struct savefile *sf;
+    struct feed *f;
 
     /* Prepare scenario by adding a feed.  The addition of an item
      * tiggers an actual write */
@@ -326,19 +326,19 @@ static int add_scan_add_scan(util_ctx_t ctx, intptr_t opaque)
     return 0;
 }
 
-typedef struct {
-    int (*setter)(feed_t *, str_t *);
-    str_t (*getter)(const feed_t *);
-} set_field_test_t;
+struct set_field_test {
+    int (*setter)(struct feed *, struct str *);
+    struct str (*getter)(const struct feed *);
+};
 
-static int set_field(util_ctx_t ctx, intptr_t opaque)
+static int set_field(struct util_ctx *ctx, intptr_t opaque)
 {
     /* Ensure the fields is setted and loaded correctly.  Set a field,
      * save, load, check the field */
 
-    savefile_t *sf;
-    feed_t *f;
-    const set_field_test_t *test = (const set_field_test_t *)opaque;
+    struct savefile *sf;
+    struct feed *f;
+    const struct set_field_test *test = (const struct set_field_test *)opaque;
 
     EXPECT(mksavefile(ctx, &sf) == 0);
     EXPECT(f = savefile_get_feed(sf, __func__));
@@ -348,22 +348,22 @@ static int set_field(util_ctx_t ctx, intptr_t opaque)
 
     EXPECT(mksavefile(ctx, &sf) == 0);
     EXPECT(f = savefile_get_feed(sf, __func__));
-    str_t value = test->getter(f);
+    struct str value = test->getter(f);
     EXPECT(str_cmp(&value, &STR_DEFINE("value")) == 0);
     savefile_free(sf);
 
     return 0;
 }
 
-static int save_only_if_needed_1(util_ctx_t ctx, intptr_t opaque)
+static int save_only_if_needed_1(struct util_ctx *ctx, intptr_t opaque)
 {
     /* Setting a feed property will enable the 'needs_write' flag.
      * If the new value of the property does not need to be changed, there
      * will be no need to write.
      */
 
-    savefile_t *sf;
-    feed_t *f;
+    struct savefile *sf;
+    struct feed *f;
 
     EXPECT(mksavefile(ctx, &sf) == 0);
     EXPECT(f = savefile_get_feed(sf, __func__));
@@ -398,11 +398,11 @@ static int save_only_if_needed_1(util_ctx_t ctx, intptr_t opaque)
     return 0;
 }
 
-static int save_only_if_needed_2(util_ctx_t ctx, intptr_t opaque)
+static int save_only_if_needed_2(struct util_ctx *ctx, intptr_t opaque)
 {
     /* Same as save_only_if_needed_1, but with flags. */
-    savefile_t *sf;
-    feed_t *f;
+    struct savefile *sf;
+    struct feed *f;
 
     EXPECT(mksavefile(ctx, &sf) == 0);
     EXPECT(f = savefile_get_feed(sf, __func__));
@@ -437,13 +437,13 @@ static int save_only_if_needed_2(util_ctx_t ctx, intptr_t opaque)
     return 0;
 }
 
-static int save_only_if_needed_3(util_ctx_t ctx, intptr_t opaque)
+static int save_only_if_needed_3(struct util_ctx *ctx, intptr_t opaque)
 {
     /* As the savefile is actually a directory where individual feeds have
      * their own file, this is checking that a file is written only if it
      * is needed, and that this does not imply writing other files. */
-    savefile_t *sf;
-    feed_t *f1, *f2, *f3;
+    struct savefile *sf;
+    struct feed *f1, *f2, *f3;
 
     EXPECT(mksavefile(ctx, &sf) == 0);
 
@@ -485,14 +485,14 @@ static int save_only_if_needed_3(util_ctx_t ctx, intptr_t opaque)
     return 0;
 }
 
-static int write_delete_write(util_ctx_t ctx, intptr_t opaque)
+static int write_delete_write(struct util_ctx *ctx, intptr_t opaque)
 {
     /* Making sure that writing twice has no effect, unless there's a
      * deletion in between.
      */
 
-    savefile_t *sf;
-    feed_t *f;
+    struct savefile *sf;
+    struct feed *f;
 
     EXPECT(mksavefile(ctx, &sf) == 0);
 
@@ -520,7 +520,7 @@ static int write_delete_write(util_ctx_t ctx, intptr_t opaque)
 
 const struct test * list_test(void)
 {
-    static const set_field_test_t set_field_tests[] = {
+    static const struct set_field_test set_field_tests[] = {
         {
             .setter = feed_set_provided_url,
             .getter = feed_get_provided_url,
