@@ -24,12 +24,3 @@
 
 void util_test_setup(const char *test_name);
 void util_test_teardown();
-
-int util_open(const char *path, int flags, mode_t mode);
-
-struct util_rss_item {
-    const char *guid;
-    const char *link;
-};
-
-int util_gen_rss(const char *path, const struct util_rss_item *);
