@@ -65,12 +65,12 @@
 
 #define EXPECT_OR_EXIT(condition) EXPECT_OR(condition, goto exit);
 
-typedef int (*test_cb_t)(util_ctx_t, intptr_t opaque);
+typedef int (*test_callback)(struct util_ctx *, intptr_t opaque);
 
 struct test {
     int enabled;
     const char *name;
-    test_cb_t callback;
+    test_callback callback;
     intptr_t opaque;
     const char *opaque_repr;
 };
