@@ -53,9 +53,9 @@ struct util_ctx {
     .test_name = NULL, \
 }
 
-static util_ctx_t util_ctx_new(void)
+static struct util_ctx *util_ctx_new(void)
 {
-    util_ctx_t ctx;
+    struct util_ctx *ctx;
 
     ctx = malloc(sizeof(*ctx));
     if (!ctx)
@@ -101,7 +101,7 @@ static void cleardir(int dirfd)
     closedir(dir);
 }
 
-static void rmtempdir(util_ctx_t ctx)
+static void rmtempdir(struct util_ctx *ctx)
 {
     if (ctx->tempdir.fd != -1) {
         cleardir(ctx->tempdir.fd);
@@ -116,7 +116,7 @@ static void rmtempdir(util_ctx_t ctx)
     }
 }
 
-static int mktempdir(util_ctx_t ctx)
+static int mktempdir(struct util_ctx *ctx)
 {
     char *dirname;
     size_t n;
@@ -153,7 +153,7 @@ fail:
     return -1;
 }
 
-static void util_ctx_del(util_ctx_t ctx)
+static void util_ctx_del(struct util_ctx *ctx)
 {
     if (ctx == NULL)
         return;
@@ -162,9 +162,9 @@ static void util_ctx_del(util_ctx_t ctx)
     free(ctx);
 }
 
-util_ctx_t util_test_setup(const char *test_name)
+struct util_ctx *util_test_setup(const char *test_name)
 {
-    util_ctx_t ctx;
+    struct util_ctx *ctx;
 
     ctx = util_ctx_new();
     if (!ctx)
@@ -174,13 +174,13 @@ util_ctx_t util_test_setup(const char *test_name)
     return ctx;
 }
 
-void util_test_teardown(util_ctx_t ctx)
+void util_test_teardown(struct util_ctx *ctx)
 {
     util_ctx_del(ctx);
     test_reset_counters();
 }
 
-int util_get_tempdir(util_ctx_t ctx)
+int util_get_tempdir(struct util_ctx *ctx)
 {
     int d;
 
