@@ -22,9 +22,9 @@
 
 #include <sys/types.h>
 
-typedef struct util_ctx *util_ctx_t;
+struct util_ctx;
 
-util_ctx_t util_test_setup(const char *test_name);
-void util_test_teardown(util_ctx_t);
+struct util_ctx *util_test_setup(const char *test_name);
+void util_test_teardown(struct util_ctx *);
 
-int util_get_tempdir(util_ctx_t);
+int util_get_tempdir(struct util_ctx *);
